/****************************************************************************
*                   optout.h
*
*  This module contains all defines, typedefs, and prototypes for OPTOUT.CPP.
*
*  from Persistence of Vision(tm) Ray Tracer
*  Copyright 1996-2002 Persistence of Vision Team
*---------------------------------------------------------------------------
*  NOTICE: This source code file is provided so that users may experiment
*  with enhancements to POV-Ray and to port the software to platforms other
*  than those supported by the POV-Ray Team.  There are strict rules under
*  which you are permitted to use this file.  The rules are in the file
*  named POVLEGAL.DOC which should be distributed with this file.
*  If POVLEGAL.DOC is not available it may be found online at -
*
*    http://www.povray.org/povlegal.html.
*
* This program is based on the popular DKB raytracer version 2.12.
* DKBTrace was originally written by David K. Buck.
* DKBTrace Ver 2.0-2.12 were written by David K. Buck & Aaron A. Collins.
*
* $File: //depot/povray/3.5/source/optout.h $
* $Revision: 1.6 $
* $Change: 1817 $
* $DateTime: 2002/07/27 10:45:37 $
* $Author: matthewgrove $
* $Log: optout.h,v $
* Revision 1.6  2003/01/01 10:58:07  matthewgrove
* MG ** First pvmpov revision, based on pvmpovray35 rev 2 **
* MG * Add pvm_hosts option.
* MG * Modify PNG file class to handle multiple streams and continue
* MG trace options.
* MG * Add hack to nullify Do_Cooperate() calls if possible.
* MG * Ensure PVM is disabled by default.
*
* Revision 1.5  2002/12/30 19:33:42  flierl
* Import of the latest sources of POV-Ray version 3.5c and MG's PVM
* patch (revision 2).
*
* Added some command line options to the configure script:
*  --enable/disable-pvm,
*  --with-pvm-incs=DIR,
*  --with-pvm-arch=ARCH,
*  --with-pvm-libs=DIR,
*  --with-pvm-auxlibs=LDFLAGS.
*
*
*****************************************************************************/


#ifndef OPTOUT_H
#define OPTOUT_H

#include "povray.h"

/*****************************************************************************
* Global preprocessor defines
******************************************************************************/

/* These are used by OPTOUT.C and the machine specific modules */

#define POV_RAY_IS_OFFICIAL 0
#define POV_RAY_VERSION "3.5"
#define POV_RAY_COPYRIGHT "Copyright 1991-2002 POV-Ray Team(tm)"
#define OFFICIAL_VERSION_NUMBER 350

#define DISTRIBUTION_MESSAGE_1 "This is an unofficial version compiled by:"
#define DISTRIBUTION_MESSAGE_2 "The PVMPOV Team http://pvmpov.sourceforge.net/"
#define DISTRIBUTION_MESSAGE_3 "The POV-Ray Team(tm) is not responsible for supporting this version."

/* Number of help pages (numbered 0 to MAX_HELP_PAGE). */

#ifdef HAVE_LIBPVM3
#define MAX_HELP_PAGE   8
#else
#define MAX_HELP_PAGE   7
#endif
/* Used by author output */

#define NUMBER_LENGTH   19
#define OUTPUT_LENGTH   15

#define NUMBER_OF_AUTHORS_ACROSS    4


/*****************************************************************************
* Global typedefs
******************************************************************************/


/*****************************************************************************
* Global variables
******************************************************************************/

/* These are available for GUI environments that may display them in a credits dialog */
extern char *Primary_Developers[];
extern char *Contributing_Authors[];
extern INTERSECTION_STATS_INFO intersection_stats[];

/*****************************************************************************
* Global functions
******************************************************************************/

void Print_Credits(void);
void Print_Options(void);
void Print_Stats(char *title, COUNTER *);
void Usage(int n, int f);
void Print_Help_Screens(void);
void Print_Authors(void);
int Banner(char *format,...);
int Statistics(char *format,...);
int Render_Info(char *format,...);
int Status_Info(char *format,...);

#endif

